@@ -334,7 +334,7 @@
 #define SSMtimbre  (port(SMtimbre, SSM_SMOOTHRATE))
 #define  SMtremelo (MIDI_SCALE*MIDIctrl[92])
 #define SSMtremelo (port(SMtremelo, SSM_SMOOTHRATE))
-#define  SMtouch   (MIDI_BIGSCALE*MIDItouch)
+#define  SMtouch   (MIDI_SCALE*MIDItouch)
 #define SSMtouch   (port(SMtouch, SSM_SMOOTHRATE))
 
 
