@@ -37,8 +37,7 @@
 */
 
 
-
-int tgen_init(tableinfo * ti, int pnum, float * p)
+int tgen_init(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)
 
 {
   int i;
@@ -51,11 +50,11 @@ int tgen_init(tableinfo * ti, int pnum, float * p)
   ti->dint = 0;
   ti->dfrac = 0;
   ti->base = 0;
-  ti->stamp = scorebeats;
+  ti->stamp = EV(scorebeats);
   if ((pnum < 1) || ((i = ti->len = ROUND(p[0])) < 1))
     epr(0,"control driver","tgen_init","Table length < 1");
   ti->lenf = (float) i;
-  ti->oconst = ((float) i)*ATIME;
+  ti->oconst = ((float) i)*EV(ATIME);
   ti->tend = i - 1;
   ti->t = (float *) calloc(i+1, sizeof(float));
   ti->llmem = 1;
@@ -70,7 +69,7 @@ int tgen_init(tableinfo * ti, int pnum, float * p)
 }
 
 
-void tgen_buzz(tableinfo * ti, int pnum, float * p)  
+void tgen_buzz(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int size, nharm, loharm, i, j;
@@ -104,7 +103,7 @@ void tgen_buzz(tableinfo * ti, int pnum, float * p)
   p[1] = (float) nharm;
   p[2] = (float) loharm;
 
-  tgen_init(ti, pnum, p);
+  tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
 
   if ((p[3] == 1.0F)||(p[3] == -1.0F))
     scale = 1.0F;
@@ -136,7 +135,7 @@ void tgen_buzz(tableinfo * ti, int pnum, float * p)
 }
 
 
-void tgen_concat_global(tableinfo * ti, int pnum, float * p)  
+void tgen_concat_global(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int i, j, k, len, tidx;
@@ -148,19 +147,19 @@ void tgen_concat_global(tableinfo * ti, int pnum, float * p)
   for (j = 1; j < pnum; j++)
     {
       i = ROUND(p[j]);
-      if ( (!gtables[i].t) || (gtables[i].len < 1))
+      if ( (!EV(gtables)[i].t) || (EV(gtables)[i].len < 1))
 	epr(0,"control driver","tgen_concat","Uninitialized/zero-lenth table");
-      len += gtables[i].len;
+      len += EV(gtables)[i].len;
     }
 
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -169,8 +168,8 @@ void tgen_concat_global(tableinfo * ti, int pnum, float * p)
   j = 0;
   while ((i < len) && (k < pnum))
     {
-      if (j < gtables[tidx].len)
-	ti->t[i++] = gtables[tidx].t[j++];
+      if (j < EV(gtables)[tidx].len)
+	ti->t[i++] = EV(gtables)[tidx].t[j++];
       else
 	{
 	  j = 0;
@@ -182,7 +181,7 @@ void tgen_concat_global(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_cubicseg(tableinfo * ti, int pnum, float * p) 
+void tgen_cubicseg(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p) 
 
 {
   int i, j, len, endpoint;
@@ -212,11 +211,11 @@ void tgen_cubicseg(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -268,7 +267,7 @@ void tgen_cubicseg(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_data(tableinfo * ti, int pnum, float * p)  
+void tgen_data(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {  
   int len, i;
@@ -279,7 +278,7 @@ void tgen_data(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     p[0] = pnum - 1;
 
-  len = tgen_init(ti, pnum, p);
+  len = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
   len = (pnum - 1 < len) ? pnum - 1 : len;
 
   i = 0;
@@ -292,7 +291,7 @@ void tgen_data(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_destroy(tableinfo * ti, int pnum, float * p)  
+void tgen_destroy(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {  
   ti->len = ti->start = ti->end = ti->tend = 0;
@@ -304,17 +303,17 @@ void tgen_destroy(tableinfo * ti, int pnum, float * p)
   if (ti->llmem)
     free(ti->t); 
   ti->llmem = 0;
-  ti->stamp = scorebeats;
+  ti->stamp = EV(scorebeats);
 }
 
-void tgen_empty(tableinfo * ti, int pnum, float * p)  
+void tgen_empty(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
-  tgen_init(ti, pnum, p);
+  tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
 }
 
 
-void tgen_expseg(tableinfo * ti, int pnum, float * p) 
+void tgen_expseg(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p) 
 
 {
   int i, j, len, dx, nx, sgn;
@@ -350,11 +349,11 @@ void tgen_expseg(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -394,13 +393,13 @@ void tgen_expseg(tableinfo * ti, int pnum, float * p)
 }
 
 
-void tgen_harm(tableinfo * ti, int pnum, float * p)
+void tgen_harm(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)
 
 {
   int i, j;
   float base, index;
 
-  i = tgen_init(ti, pnum, p);
+  i = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
   base = 6.283185F/i;
   i--;
 
@@ -416,13 +415,13 @@ void tgen_harm(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_harm_phase(tableinfo * ti, int pnum, float * p)
+void tgen_harm_phase(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)
 
 {
   int i, j;
   float base, index, k;
 
-  i = tgen_init(ti, pnum, p);
+  i = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
   base = 6.283185F/i;
   i--;
 
@@ -443,7 +442,7 @@ void tgen_harm_phase(tableinfo * ti, int pnum, float * p)
 }
 
 
-void tgen_lineseg(tableinfo * ti, int pnum, float * p) 
+void tgen_lineseg(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p) 
 
 {
   int i, j, len, dx, nx;
@@ -471,11 +470,11 @@ void tgen_lineseg(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -514,13 +513,13 @@ void tgen_lineseg(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_periodic(tableinfo * ti, int pnum, float * p)  
+void tgen_periodic(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int i, j;
   float base, index;
 
-  i = tgen_init(ti, pnum, p);
+  i = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
   base = 6.283185F/i;
   i--;
 
@@ -540,7 +539,7 @@ void tgen_periodic(tableinfo * ti, int pnum, float * p)
 }
 
 
-void tgen_polynomial(tableinfo * ti, int pnum, float * p) 
+void tgen_polynomial(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p) 
 
 {
   float scale, yval, ynth;
@@ -549,7 +548,7 @@ void tgen_polynomial(tableinfo * ti, int pnum, float * p)
   if (pnum < 4)
     epr(0,"control driver","tgen_polynomial","Too few parameters");
 
-  tgen_init(ti, pnum, p);
+  tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     
   scale = (1.0F/p[0])*(p[2]-p[1]);
 
@@ -576,7 +575,7 @@ void tgen_polynomial(tableinfo * ti, int pnum, float * p)
 #define RAN_GAUSS   4
 #define RAN_PPROC   5
 
-void tgen_random(tableinfo * ti, int pnum, float * p)  
+void tgen_random(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int dist, i, j;
@@ -585,7 +584,7 @@ void tgen_random(tableinfo * ti, int pnum, float * p)
   if (pnum < 3)
     epr(0,"control driver","tgen_random","Too few parameters");
 
-  tgen_init(ti, pnum, p);
+  tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
 
   dist = ROUND(p[1]);
     
@@ -666,7 +665,7 @@ void tgen_random(tableinfo * ti, int pnum, float * p)
 #define SAMP_LLMEM     1
 #define SAMP_DATABLOCK 5
 
-void tgen_sample(tableinfo * ti, int pnum, float * p)  
+void tgen_sample(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int i;
@@ -677,18 +676,18 @@ void tgen_sample(tableinfo * ti, int pnum, float * p)
 
   ti->len = pnum - SAMP_DATABLOCK;
   ti->lenf = (float)(pnum - SAMP_DATABLOCK);
-  ti->oconst = ti->lenf*ATIME;
+  ti->oconst = ti->lenf*EV(ATIME);
 
   if (ti->llmem)
     free(ti->t); 
   ti->t = p;
 
-  ti->stamp = scorebeats;
+  ti->stamp = EV(scorebeats);
 
   if (p[pnum - SAMP_SR] > 0)
     {
       ti->sr = p[pnum - SAMP_SR];
-      if (p[pnum - SAMP_SR] == ARATE)
+      if (p[pnum - SAMP_SR] == EV(ARATE))
 	{
 	  ti->dint = 1;
 	  ti->dfrac = 0;
@@ -696,13 +695,13 @@ void tgen_sample(tableinfo * ti, int pnum, float * p)
       else
 	{
 	  ti->dfrac = 4294967296.0*
-	    modf(((double)p[pnum - SAMP_SR])/((double)ARATE), &intdummy);
+	    modf(((double)p[pnum - SAMP_SR])/((double)EV(ARATE)), &intdummy);
 	  ti->dint = intdummy;
 	}
     }
   else
     {
-      ti->sr = ARATE;
+      ti->sr = EV(ARATE);
       ti->dint = 1;
       ti->dfrac = 0;
     }
@@ -711,7 +710,7 @@ void tgen_sample(tableinfo * ti, int pnum, float * p)
 
   if (p[pnum - SAMP_SR] > 0)
     {
-      if (ARATE >= p[pnum - SAMP_SR])
+      if (EV(ARATE) >= p[pnum - SAMP_SR])
 	{
 	  ti->sffl = 1.0F;
 	  ti->sfui = 0x00010000;
@@ -719,8 +718,8 @@ void tgen_sample(tableinfo * ti, int pnum, float * p)
 	}
       else
 	{
-	  if ((ARATE*SINC_UPMAX) >= p[pnum - SAMP_SR])
-	    ti->sffl = (ARATE/ti->sr);
+	  if ((EV(ARATE)*SINC_UPMAX) >= p[pnum - SAMP_SR])
+	    ti->sffl = (EV(ARATE)/ti->sr);
 	  else
 	    ti->sffl = (1.0F/SINC_UPMAX);
 	  ti->sfui = ((float)(pow(2,16)))*ti->sffl + 0.5F;
@@ -778,7 +777,7 @@ void tgen_sample(tableinfo * ti, int pnum, float * p)
 #undef SAMP_DATABLOCK 
 
 
-void tgen_spline(tableinfo * ti, int pnum, float * p)  
+void tgen_spline(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int i, j, len, endpoint, newpoint;
@@ -808,11 +807,11 @@ void tgen_spline(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -870,7 +869,7 @@ void tgen_spline(tableinfo * ti, int pnum, float * p)
 
 }
 
-void tgen_step(tableinfo * ti, int pnum, float * p)  
+void tgen_step(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int i, j, len, nx;
@@ -897,11 +896,11 @@ void tgen_step(tableinfo * ti, int pnum, float * p)
   if (p[0] <= 0.0F)
     {
       p[0] = len;
-      tgen_init(ti, pnum, p);
+      tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
     }
   else
     {
-      j = tgen_init(ti, pnum, p);
+      j = tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
       len = (j < len) ? j : len; 
     }
 
@@ -954,7 +953,7 @@ double tgen_bessel(double x)
 #define WIN_KAISER   5
 #define WIN_BOXCAR   6
 
-void tgen_window(tableinfo * ti, int pnum, float * p)  
+void tgen_window(ENGINE_PTR_DECLARE_COMMA tableinfo * ti, int pnum, float * p)  
 
 {
   int type,i;
@@ -964,7 +963,7 @@ void tgen_window(tableinfo * ti, int pnum, float * p)
   if (pnum < 2)
     epr(0,"control driver","tgen_window","Too few parameters");
 
-  tgen_init(ti, pnum, p);
+  tgen_init(ENGINE_PTR_COMMA ti, pnum, p);
 
   type = ROUND(p[1]);
     
@@ -1027,14 +1026,6 @@ void tgen_window(tableinfo * ti, int pnum, float * p)
 #undef WIN_KAISER   
 #undef WIN_BOXCAR   
 
-
-
 /* ************************* */
-/* end of  table generators  */
+/*  end of table generators  */
 /* ************************* */
-
-
-
-
-
-
