@@ -167,7 +167,7 @@ void optglobalblock(void)
 
   globalreferinit();
   vmcheck(ginstr = (sigsym*) malloc(sizeof(sigsym)));
-  vmcheck(ginstr->cref = (crefer *) calloc(1L, sizeof(crefer)));
+  vmcheck(ginstr->cref = (crefer *) calloc(1, sizeof(crefer)));
 
   /* update rate for global exprs and opcodes */
 
@@ -323,13 +323,13 @@ void symtableinit(sigsym * iptr)
   sigsym * sptr;
   tnode * tptr;
 
-  vmcheck(iptr->cref = (crefer *) calloc(1L, sizeof(crefer)));
+  vmcheck(iptr->cref = (crefer *) calloc(1, sizeof(crefer)));
 
   sptr = iptr->defnode->sptr;
   while (sptr != NULL)
     {
 
-      vmcheck(sptr->tref = (trefer *) calloc(1L, sizeof(trefer)));
+      vmcheck(sptr->tref = (trefer *) calloc(1, sizeof(trefer)));
 
       switch(sptr->kind) {
       case K_PFIELD: 
@@ -602,7 +602,7 @@ void duradd(sigsym * iptr)
   if (iptr->cref->idur || iptr->cref->kadur)
     {
       sptr = addvsymend(&(iptr->defnode->sptr), "_dur" , K_NORMAL);
-      vmcheck(sptr->tref = (trefer *) calloc(1L, sizeof(trefer)));
+      vmcheck(sptr->tref = (trefer *) calloc(1, sizeof(trefer)));
 
       sptr->rate = IRATETYPE;
       sptr->res = ASFLOAT;
@@ -826,7 +826,7 @@ void globalreferinit(void)
       /* currently being used for tables only      */
       /* to expand to variables see symtableinit() */
 
-      vmcheck(sptr->tref = (trefer *) calloc(1L, sizeof(trefer)));
+      vmcheck(sptr->tref = (trefer *) calloc(1, sizeof(trefer)));
 
       /* -1 codes "no instrument last touched this variable. if */
       /* it remains after reference count, either its 0 or the  */
@@ -864,7 +864,7 @@ void dotablepromote(sigsym * sptr)
   globalsymtable->width = 1;
   globalsymtable->defnode = sptr->defnode;
   globalsymtable->consval = sptr->consval;
-  vmcheck(globalsymtable->tref = (trefer *) calloc(1L, sizeof(trefer)));
+  vmcheck(globalsymtable->tref = (trefer *) calloc(1, sizeof(trefer)));
 
   sptr->defnode->down->next->val = newname;
 
