@@ -115,7 +115,7 @@ int main(int argc, char ** argv)
   toptree(PRINTKPASS);
   toptree(PRINTAPASS);
   printtablefunctions();                      /* readscore.c */
-  postscript();                               /* writemain.c */
+  postscript();                               /* writeorc.c */
 
 
   /*~~~~~~~~~~~~~~~~~~*/
@@ -238,7 +238,7 @@ void sfrontshutdown(void)
 
 
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
-/* the first set of functions print out long user messages      */
+/* the first set of functions print out extended user messages  */
 /*______________________________________________________________*/
 
 
@@ -632,6 +632,8 @@ void deletecppfiles(void)
 void sfrontpostparsecheck(void)
 
 {
+  int len;
+
   if ((saolfilelist == NULL)&&(bitfile == NULL))
     {
       printf("Error:  -orc, -bit, or -bitc option is required.\n");
@@ -661,10 +663,115 @@ void sfrontpostparsecheck(void)
   if (ain && aout && (ain != aout) &&
       (ainflow == ACTIVE_FLOW) && (aoutflow == ACTIVE_FLOW))
     {      
-      printf("Error: -ain and -aout drivers are both active-flow drivers.\n");
+      printf("Error: -ain and -aout drivers are both active-flow drivers.\n\n");
       printhelpshort();
     }
 
+  if (reentrant)
+    {
+      if (cin && !creentrant)
+	{      
+	  printf("Error: The non-reentrant -cin driver is incompatible with\n");
+	  printf("       the re-entrant -aout or -ain driver.\n\n");
+	  printhelpshort();
+	}
+      if (session)
+	{      
+	  printf("Error: Sfront networking is incompatible with\n");
+	  printf("       the re-entrant -aout or -ain driver.\n\n");
+	  printhelpshort();
+	}
+    }
+
+  if ((cin && (!strcmp(cinname,"aucontrol") || !strcmp(cinname,"aucontrolm"))) ||
+      (ain && (!strcmp(ainname,"audiounit") || !strcmp(ainname,"audiounit_debug"))) ||
+      (aout && (!strcmp(aoutname,"audiounit") || !strcmp(aoutname,"audiounit_debug"))))
+    {
+      if (ain && aout && cin && !strcmp(cinname, "aucontrol"))
+	au_component_type = dupval("aufx");
+
+      if (ain && aout && cin && !strcmp(cinname, "aucontrolm"))
+	au_component_type = dupval("aumf");
+
+      if (!ain && aout && cin && !strcmp(cinname, "aucontrolm"))
+	au_component_type = dupval("aumu");
+
+      if (!au_component_type)
+	{
+	  printf("Error: Unsupported combination of AudioUnit drivers:\n");
+
+	  printf("       ");
+	  if (aout &&(!strcmp(aoutname,"audiounit") || !strcmp(aoutname,"audiounit_debug")))
+	    printf("-aout %s ", aoutname);
+	  if ((cin && (!strcmp(cinname,"aucontrol") || !strcmp(cinname,"aucontrolm"))))
+	    printf("-cin %s ", cinname);
+	  if (ain && (!strcmp(ainname,"audiounit") || !strcmp(ainname,"audiounit_debug")))
+	    printf("-ain %s", ainname);
+	  printf("\n\n");
+	  
+	  printf("       Supported combinations:\n");
+	  printf("       -aout audiounit -cin aucontrol  -ain audiounit (Effect)\n");
+	  printf("       -aout audiounit -cin aucontrolm -ain audiounit (MusicEffect)\n");
+	  printf("       -aout audiounit -cin aucontrolm                (MusicDevice)\n");
+	  printf("\n       (audiounit_debug may substitute for audiounit)\n");
+	  noerrorplace();
+	}
+
+      if (!au_filesystem_name)
+	{
+	  if (!saolfilelist)
+	    {
+	      printf("Error: -au_filesystem_name flag is required for AUs built"
+		     "from -bit/-bitc files.\n");
+	      noerrorplace();
+	    }
+
+	  au_filesystem_name = dupval(saolfilelist->val);
+	  len = strlen(au_filesystem_name);
+
+	  if ((len > 5) && (!strcmp(&(au_filesystem_name[len - 5]), ".saol") ||
+			    !strcmp(&(au_filesystem_name[len - 5]),".SAOL")))
+	    {
+	      au_filesystem_name[len - 5] = '\0';
+	      au_filesystem_name[len - 4] = '\0';
+	      au_filesystem_name[len - 3] = '\0';
+	      au_filesystem_name[len - 2] = '\0';
+	      au_filesystem_name[len - 1] = '\0';
+	    }
+	}
+
+      /* au_component_subtype */
+
+      if (!au_component_subtype)
+	{
+	  au_component_subtype = dupval("wxyz");
+	  au_component_subtype[0] = au_filesystem_name[0];
+	  len = strlen(au_filesystem_name);
+	  au_component_subtype[1] = ((len > 1) ? 
+				     au_filesystem_name[1] : au_component_subtype[1]);
+	  au_component_subtype[2] = ((len > 2) ? 
+				     au_filesystem_name[2] : au_component_subtype[2]);
+	  au_component_subtype[3] = ((len > 3) ? 
+				     au_filesystem_name[3] : au_component_subtype[3]);
+	}
+
+      if (!au_ui_name)
+	au_ui_name = dupval(au_filesystem_name);
+      if (!au_component_manu)
+	au_component_manu = dupval("Xmpl");
+      if (!au_ui_manu)
+	au_ui_manu = dupval("Example");
+      if (!au_manu_url)
+	au_manu_url = dupval("com.example");
+
+      if (!strcmp(au_component_type, "aufx"))
+	printf("Making an Effect AudioUnit\n\n");
+      if (!strcmp(au_component_type, "aumf"))
+	printf("Making a MusicEffect AudioUnit\n\n");
+      if (!strcmp(au_component_type, "aumu"))
+	printf("Making a MusicDevice AudioUnit\n\n");
+    }
+
   cinmaxchan = cmaxchan;
 
   if (session)
@@ -763,7 +870,7 @@ int oneparamflags(char * s1, char * s2)
 {  
   int od, i, q1, q2, q3, q4; 
   float f;
-  char * name1, * name2;
+  char * name1, * name2, * sptr;
 
   /* all files */
 
@@ -937,7 +1044,7 @@ int oneparamflags(char * s1, char * s2)
 
       if (strlen(s2) < MINIMUM_SESSIONKEY)
 	{
-	  printf("Error: Passphrase \"%s\" less than %i characters long.\n\n",
+	  printf("Error: Passphrase \"%s\" less than %i characters in length.\n\n",
 		 s2, MINIMUM_SESSIONKEY);
 	  printhelpshort();
 	}
@@ -976,6 +1083,133 @@ int oneparamflags(char * s1, char * s2)
       return 1;
     }
 
+  if (!strcmp(s1,"-au_component_manu"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_component_manu parameter.\n");
+	  noerrorplace();
+	}
+
+      if (strlen(s2) != 4)
+	{
+	  printf("Error: -au_component_manu code \"%s\" is not exactly 4 characters in length.\n",
+		 s2);
+	  noerrorplace();
+	}
+
+      au_component_manu = dupval(s2);
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_component_subtype"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_component_subtype parameter.\n");
+	  noerrorplace();
+	}
+
+      if (strlen(s2) != 4)
+	{
+	  printf("Error: -au_component_subtype code \"%s\" is not exactly 4 characters in length.\n",
+		 s2);
+	  noerrorplace();
+	}
+
+      au_component_subtype = dupval(s2);
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_filesystem_name"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_filesystem_name parameter.\n");
+	  noerrorplace();
+	}
+
+      au_filesystem_name = dupval(s2);
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_manu_url"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_manu_url parameter.\n");
+	  noerrorplace();
+	}
+
+      au_manu_url = dupval(s2);
+
+      if ((sptr = strcasestr(au_manu_url, ".audiounit")))
+	*sptr = '\0';
+
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_ui_name"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_ui_name parameter.\n");
+	  noerrorplace();
+	}
+
+      au_ui_name = dupval(s2);
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_ui_manu"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_ui_manu parameter.\n");
+	  noerrorplace();
+	}
+
+      au_ui_manu = dupval(s2);
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_view_bundlename"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_view_bundlename parameter.\n");
+	  noerrorplace();
+	}
+
+      au_view_bundlename = dupval(s2);
+
+      if ((sptr = strcasestr(au_view_bundlename, ".bundle")))
+	*sptr = '\0';
+
+      return 1;
+    }
+
+  if (!strcmp(s1,"-au_view_baseclass"))
+    {
+       
+      if (!s2)
+	{
+	  printf("Error: Missing -au_view_baseclass parameter.\n");
+	  noerrorplace();
+	}
+
+      au_view_baseclass = dupval(s2);
+
+      return 1;
+    }
+
   if (!strcmp(s1,"-sinc_zcross"))
     {
       if (!s2 || (sscanf(s2, "%f", &f) != 1))
