@@ -40,7 +40,7 @@
 #ifndef _SFRONT_TREE_H
 #define _SFRONT_TREE_H 1
 
-#define IDSTRING "0.91 07/30/06"
+#define IDSTRING "0.95 12/28/09"
 
 #include <stdio.h>
 #include <math.h>
@@ -632,7 +632,7 @@ extern void * alloca(size_t);
 
 #define NO_NETWORKING  0
 #define HAS_NETWORKING 1
-#define NET_STATUS     HAS_NETWORKING
+#define NET_STATUS     NO_NETWORKING
 
 /* default SIP location */
 
@@ -1054,7 +1054,7 @@ int s_params;
 typedef struct aiffmark {
 
 short id;
-unsigned long position;
+unsigned int position;
 struct aiffmark * next;
 
 } aiffmark;
@@ -1102,6 +1102,11 @@ extern int cinmaxchan;
 extern int clatency;
 extern char * cinname;
 
+extern int reentrant;
+extern int creentrant;
+extern int nomain;
+extern int adebug;
+
 extern int timeoptions;
 extern float latency;
 extern int catchsignals;
@@ -1123,6 +1128,15 @@ extern int netmsets;
 extern unsigned short sip_port;
 extern char sip_ip[];
 extern int msession_interval;
+extern char * au_component_type;
+extern char * au_component_manu;
+extern char * au_component_subtype;
+extern char * au_filesystem_name;
+extern char * au_ui_name;
+extern char * au_ui_manu;
+extern char * au_manu_url;
+extern char * au_view_bundlename;
+extern char * au_view_baseclass;
 
 extern tnode * saolfilelist;
 extern tnode * saslfilelist;
@@ -1147,6 +1161,7 @@ extern struct hasarray has;
 
 extern int srate;
 extern int krate;
+extern int saol_krate;
 extern int twocycle;
 extern int inchannels;
 extern int outchannels;
@@ -1154,8 +1169,8 @@ extern int interp;
 extern float globaltune;
 
 extern int interp_cmdline;
-extern unsigned long sinc_pilen;
-extern unsigned long sinc_zcross;
+extern unsigned int sinc_pilen;
+extern unsigned int sinc_zcross;
 extern float sinc_upmax;
 
 extern tnode * troot;
@@ -1257,7 +1272,7 @@ typedef struct sasdata {
   sigsym * labeltable;
   int numlabels;
 
-  unsigned long scorefsize;
+  unsigned int scorefsize;
   
   char * endtimeval;
 
@@ -1282,12 +1297,12 @@ typedef struct midata {
   tnode * imidiroot;         /* list of midi events */
   tnode * imiditail;
 
-  unsigned long midifsize;   /* midi file size, for mp4write */
+  unsigned int midifsize;   /* midi file size, for mp4write */
 
-  unsigned long miditracks;  /* track counter for extchan */
-  unsigned long miditicks;   /* ticks per quarter note */
-  unsigned long midimaxtime; /* maximum timestamp in file */
-  long midinumchan;          /* extended channels in use */
+  unsigned int miditracks;  /* track counter for extchan */
+  unsigned int miditicks;   /* ticks per quarter note */
+  unsigned int midimaxtime; /* maximum timestamp in file */
+  int midinumchan;          /* extended channels in use */
 
 } midata;
 
@@ -1299,9 +1314,9 @@ extern int midiallsoundsoff;
 /* temporary midi variables */
 
 extern unsigned char midirunstat;
-extern unsigned long midictime;
+extern unsigned int midictime;
 extern unsigned int midibank[];
-extern long midiext[];
+extern int midiext[];
 extern int midifirst[];
 extern tnode * midicurrinstr[];
 extern tnode * midicurrnote[];
@@ -1322,7 +1337,7 @@ extern unsigned char bitstoread;  /* buffers for mp4 binary read */
 extern int bitreadpos;            /* keeps track of bit position */
                                 
                                   /* for mp4 binary intrachunk read */
-extern unsigned long bitreadlen;  /* number of bytes left in chunk */
+extern unsigned int bitreadlen;  /* number of bytes left in chunk */
 extern int bitscoretype;          /* type of line read in progress */
 extern int bitlinecount;          /* score line finished */
 extern float bitscotime;          /* score time */
@@ -1340,7 +1355,6 @@ extern int bitwritepos;
 
 extern unsigned char bitstoread;
 extern int bitreadpos;
-extern unsigned long bitreadlen;
 
 extern int bitwritenosymbols;
 
@@ -1401,14 +1415,14 @@ typedef struct sampleinfo {
   char numbytes;        /* number of bytes in a data word         */
   char framebytes;      /* number of bytes in one N-channel frame */
   char chanpoint;       /* 1st byte of channel in frame; -1 sum to mono */
-  unsigned long len;    /* number of samples                      */
-  unsigned long point;  /* number of bytes before first data byte */
-  unsigned long srate;  /* sampling rate */
+  unsigned int len;    /* number of samples                      */
+  unsigned int point;  /* number of bytes before first data byte */
+  unsigned int srate;  /* sampling rate */
   char hasbase;         /* has a base frequency */
   char hasloop;         /* has loop points */
   float base;           /* base frequency */
-  unsigned long start;  /* start of loop */
-  unsigned long end;    /* end of loop */
+  unsigned int start;  /* start of loop */
+  unsigned int end;    /* end of loop */
 
 } sampleinfo;
 
@@ -1430,6 +1444,8 @@ extern int aoutfilecheck(char *);
 extern int makeaudiotypeout(int);
 extern int stdoutused(int);
 extern int stdinused(int);
+extern int wiretap_logging(int);
+extern int adriver_reflection(int);
 extern int makeaudiotypein(int);
 extern void audiodefaults(void);
 extern void makeainparams(int, int *, int *);
@@ -1438,6 +1454,8 @@ extern int makeaoutsync(int);
 extern int makeainsync(int);
 extern int makeaouttimedefault(int);
 extern int makeaintimedefault(int);
+extern int makeaoutrobust(int);
+extern int makeainrobust(int);
 
 /* from blocktree.c */
 
@@ -1520,8 +1538,8 @@ extern int lexstate_wmap(void);
 
 /* from mp4read.c */
 
-extern unsigned long readbit(unsigned long);
-extern void readflush(unsigned long);
+extern unsigned int readbit(unsigned int);
+extern void readflush(unsigned int);
 extern int readprepare(int);
 extern int orclex(void);
 extern tnode * binconflex(void);
@@ -1619,6 +1637,8 @@ extern void varupdate(tnode *, sigsym**);
 
 extern void readmidi(midata *, sasdata *, int type);
 extern void initmidiinstr(int, sigsym *, int *);
+extern void initmidiinstrassign(int, sigsym *);
+extern void initmidiinstrconstant(int, sigsym *);
 extern void binmidiwrite(int);
 extern void midieventread(void);
 
@@ -1627,10 +1647,20 @@ extern void midieventread(void);
 extern void readscore(int);
 extern void printtablefunctions(void);
 extern void initendtime(void);
+extern void initendtimeassign(void);
 extern void initscoreinstr(int, sigsym * sptr);
+extern void initscoreinstrassign(int, sigsym * sptr);
+extern void initscoreinstrconstant(int, sigsym * sptr);
 extern void initscorecontrol(int);
+extern void initscorecontrolassign(int);
+extern void initscorecontrolconstant(int);
 extern void initscoretempo(int);
-extern void initscoretable(int);
+extern void initscoretempoassign(int);
+extern void initscoretempoconstant(int);
+extern void initscoretableexterns(int);
+extern void initscoretablevars(int);
+extern void initscoretableassign(int);
+extern void initscoretableconstant(int);
 extern int parsetempo(sasdata *, tnode *, int);
 extern int parsecontrol(sasdata *, tnode *, int);
 extern void mergescores(void);
@@ -1676,7 +1706,7 @@ extern int      movebefore(sigsym **,sigsym *,sigsym *);
 extern char *   dupval(char * val);
 extern char *   dupunderscore(char * val);
 extern tnode *  make_tnode(char *, int);
-extern long     make_long(tnode * tptr);
+extern int      make_int(tnode * tptr);
 extern int      largeinteger(char * s);
 extern int      reachableinstrexeff(sigsym *);
 extern int      reachableinstrexstart(sigsym *);
@@ -1721,7 +1751,6 @@ extern  int stname_cbr(tnode * aptr);
 /* from writeorc.c */
 
 extern void toptree(int);
-extern void printsaoltables(int);
 extern void postscript(void);
 extern int shadowcheck(void);
 extern char * inputbusmacro(void);
@@ -1730,6 +1759,8 @@ extern char * inputbusmacro(void);
 
 extern void preamble(void);
 extern void postcorefunctions(void);
+extern void printsaoltables(int);
+extern void printtablecatalog(void);
 
 /* from wtparse.c */
 
